# -*- coding: utf-8 -*-
# Copyright (c) 2012  Infrae. All rights reserved.
# See also LICENSE.txt
import unittest
import localdatetime
from DateTime import DateTime
from datetime import datetime


class LocalTimeTestCase(unittest.TestCase):

    def test_get_formatted_date_datetime(self):
        # Test some dates from different locales
        dt = datetime(2005, 0o2, 0o1, 19, 13)

        fd = localdatetime.get_formatted_date(
            dt, size="short", locale="nl")
        self.assertEqual('1-2-05 19:13', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="medium", locale="nl")
        self.assertEqual('1-feb-2005 19:13:00', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="long", locale="nl")
        self.assertEqual('1 februari 2005 19:13:00 +000', fd)

    def test_get_formatted_date_invalid_locale(self):
        """If the local is invalid, it should fallback to english.
        """
        dt = datetime(2005, 0o2, 0o1, 19, 13)

        # Test invalid local
        fd = localdatetime.get_formatted_date(
            dt, size="long", locale="u1")
        self.assertEqual('February 1, 2005 7:13:00 PM +000', fd)

    def test_get_formatted_date_tuple(self):
        # test some dates from different locales
        dt = [int(p) for p in DateTime('2005-02-01 19:13').parts()[:6]]

        fd = localdatetime.get_formatted_date(
            dt, size="short", locale="nl")
        self.assertEqual('1-2-05 19:13', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="medium", locale="nl")
        self.assertEqual('1-feb-2005 19:13:00', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="long", locale="nl")
        self.assertEqual('1 februari 2005 19:13:00 +000', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="full", locale="nl")
        self.assertEqual('dinsdag 1 februari 2005 19:13:00 uur +000', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="short", locale="en")
        self.assertEqual('2/1/05 7:13 PM', fd)

        fd = localdatetime.get_formatted_date(
            dt, size="short", locale="en-za")
        self.assertEqual('2005/02/01 7:13 PM', fd)

    def test_month_utilities(self):
        # test the month names of certain locales
        months = localdatetime.get_month_names(locale='nl')
        self.assertEqual(['januari', 'februari', 'maart', 'april',
                    'mei', 'juni', 'juli', 'augustus', 'september',
                    'oktober', 'november', 'december'], months)

        monthabbrs = localdatetime.get_month_abbreviations(locale='nl')
        self.assertEqual(['jan', 'feb', 'mrt', 'apr', 'mei', 'jun',
                    'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
                    monthabbrs)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(LocalTimeTestCase))
    return suite
